@@ -2,6 +2,8 @@
 from .JieQi import JieQi
 from .NineStar import NineStar
 from .EightChar import EightChar
+from .ShuJiu import ShuJiu
+from .Fu import Fu
 from .Solar import Solar
 from .SolarWeek import SolarWeek
 from .SolarMonth import SolarMonth
